@@ -5,7 +5,7 @@ YAZAR_POSTA = 'keyiflerolsun@gmail.com'
 
 PAKET       = 'TRSehirler'
 
-VERSIYON    = '0.1.0'
+VERSIYON    = '0.1.1'
 
 REPO        = 'https://github.com/keyiflerolsun/TRSehirler'
 ACIKLAMA    = 'Türkiye Cumhuriyeti Devleti Şehirlerini; İl, Plaka, Telefon veya İlçe bilgisinden bulun..'
@@ -13,7 +13,8 @@ ANAHTAR_KLM = ['TRSehirler', 'KekikAkademi', 'keyiflerolsun']
 
 GEREKSINIM  = [
     "tinydb==4.2.0",
-    "tabulate==0.8.7"
+    "tabulate==0.8.7",
+    "attrdict==2.0.1"
 ]
 
 from TRSehirler.Sehirler import Sehir
\ No newline at end of file
